/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Frontend - abstract-button-toolbar.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  Directive,
  ElementRef,
  Injector,
  Input,
  OnInit,
  Output,
  ViewChild,
} from "@angular/core";
import {Navigate} from "@ngxs/router-plugin";
import {
  BehaviorSubject,
  Observable,
} from "rxjs";
import {AbstractInternalPresentational} from "../../../../core/components/presentationals/abstract-internal/abstract-internal.presentational";
import {ButtonColorEnum} from "../../../../core/enums/button-color.enum";
import {ExtraButtonToolbar} from "../../../../core/models/datatable/extra-button-toolbar.model";
import {BaseResource} from "../../../../core/models/dto/base-resource.model";
import {
  isNotNullNorUndefined,
  isTruthyObject,
} from "../../../../core/tools/is/is.tool";
import {ObservableUtil} from "../../../../core/utils/observable.util";
import {SsrUtil} from "../../../../core/utils/ssr.util";

// @dynamic
@Directive()
// eslint-disable-next-line @angular-eslint/directive-class-suffix
export abstract class AbstractButtonToolbarPresentational<TResourceModel extends BaseResource> extends AbstractInternalPresentational implements OnInit {
  @Input()
  readonly keyBackButtonToTranslate: string = this.labelTranslateInterface.applicationBackToList;

  @Input()
  isLoading: boolean;

  _listExtraButtons?: ExtraButtonToolbar<TResourceModel>[];

  @Input()
  set listExtraButtons(value: ExtraButtonToolbar<TResourceModel>[]) {
    this._listExtraButtons = value;
    this._mergeExtraButtonWithButtons();
  }

  get listExtraButtons(): ExtraButtonToolbar<TResourceModel>[] {
    return this._listExtraButtons;
  }

  @Input()
  listExtraSmallButtons?: ExtraButtonToolbar<TResourceModel>[];

  listOriginalButton?: ExtraButtonToolbar<TResourceModel>[];
  listButtonMerged?: ExtraButtonToolbar<TResourceModel>[];

  private readonly _backToListBS: BehaviorSubject<void> = new BehaviorSubject<void>(undefined);
  @Output("backToListChange")
  readonly backToListObs: Observable<void> = ObservableUtil.asObservable(this._backToListBS);

  private readonly _navigateBS: BehaviorSubject<Navigate> = new BehaviorSubject<Navigate>(undefined);
  @Output("navigateChange")
  readonly navigateObs: Observable<Navigate> = ObservableUtil.asObservable(this._navigateBS);

  @ViewChild("mainButtonElement", {static: true})
  mainButtonElement: ElementRef;

  get buttonColorEnum(): typeof ButtonColorEnum {
    return ButtonColorEnum;
  }

  constructor(protected readonly _injector: Injector) {
    super(_injector);
  }

  focusFirstButtonElement(): void {
    if (SsrUtil.isServer) {
      return;
    }
    setTimeout(() => {
      if (isTruthyObject(this.mainButtonElement)) {
        this.mainButtonElement.nativeElement.querySelectorAll("*").forEach((elementToFocus: HTMLElement) => {
            elementToFocus.focus();
          },
        );
      }
    });
  }

  ngOnInit(): void {
    super.ngOnInit();
    this._mergeExtraButtonWithButtons();
  }

  private _mergeExtraButtonWithButtons(): void {
    const originalButtons = isNotNullNorUndefined(this.listOriginalButton) ? this.listOriginalButton : [];
    const extraButtons = isNotNullNorUndefined(this.listExtraButtons) ? this._listExtraButtons : [];
    this.listButtonMerged = [...originalButtons, ...extraButtons];
    this.listButtonMerged.sort((a, b) => {
      const orderA = a.order || 0;
      const orderB = b.order || 0;
      if (orderA === orderB) {
        return 0;
      } else if (orderA < orderB) {
        return -1;
      }
      return 1;
    });
  }

  backToList(): void {
    this._backToListBS.next();
  }

  navigate(navigate: Navigate): void {
    this._navigateBS.next(navigate);
  }
}
