/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Frontend - data-table.presentational.spec.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {NO_ERRORS_SCHEMA} from "@angular/core";
import {
  ComponentFixture,
  TestBed,
  waitForAsync,
} from "@angular/core/testing";
import {TranslateService} from "@ngx-translate/core";

import {QueryParameters} from "../core/models/query-parameters/query-parameters.model";
import {MockTranslatePipe} from "../core/tests/helpers/mock-translate.pipe";
import {MockTranslateService} from "../core/tests/helpers/mock-translate.service";
import {DataTablePresentational} from "./data-table.presentational";

xdescribe("DataTablePresentational", () => {
  let component: DataTablePresentational<any>;
  let fixture: ComponentFixture<any>;

  beforeEach(waitForAsync(() => {
    TestBed.configureTestingModule({
      declarations: [DataTablePresentational, MockTranslatePipe],
      providers: [
        {
          provide: TranslateService,
          useClass: MockTranslateService,
        },
      ],
      schemas: [NO_ERRORS_SCHEMA],
    })
      .compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(DataTablePresentational);
    component = fixture.componentInstance;
    component.queryParameters = new QueryParameters();
    component.columns = [];
    fixture.detectChanges();
  });

  it("should create", () => {
    expect(component).toBeTruthy();
  });

  describe("getData", () => {
    it("should return nested data", () => {
      const when = "2019-08-22T09:34:27.603+0200";
      const result = component.getData({
          creation: {
            when: when,
          },
        },
        {field: "creation.when"} as any);

      expect(result).toBe(when);
    });
  });
});
